_xmlNs

Struct _xmlNs 

#[repr(C)]
pub struct _xmlNs { pub next: *mut _xmlNs, pub type_: xmlNsType, pub href: *const xmlChar, pub prefix: *const xmlChar, pub _private: *mut c_void, pub context: *mut _xmlDoc, }
An XML namespace. Note that prefix == NULL is valid, it defines the default namespace within the subtree (until overridden).

xmlNsType is unified with xmlElementType.

Note that the XPath engine returns XPath namespace nodes as xmlNs cast to xmlNode. This is a terrible design decision that can easily cause type confusion errors. In this case, the next member points to the xmlNode element to which the namespace node belongs.

Fields

next: *mut _xmlNs

next namespace

type_: xmlNsType

XML_NAMESPACE_DECL

href: *const xmlChar

namespace URI

prefix: *const xmlChar

namespace prefix

_private: *mut c_void

application data

context: *mut _xmlDoc

normally an xmlDoc