endElementNsSAX2Func

Type Alias endElementNsSAX2Func 

pub type endElementNsSAX2Func = Option<unsafe extern "C" fn(ctx: *mut c_void, localname: *const xmlChar, prefix: *const xmlChar, URI: *const xmlChar)>;
SAX2 callback for end tags.

It provides the namespace information for the element.

@param ctx the user data (XML parser context) @param localname the local name of the element @param prefix the element namespace prefix if available @param URI the element namespace name if available

Aliased Type

pub enum endElementNsSAX2Func {
    None,
    Some(unsafe extern "C" fn(*mut c_void, *const u8, *const u8, *const u8)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, *const u8, *const u8, *const u8))

Some value of type T.