xmlCharEncodingOutputFunc

Type Alias xmlCharEncodingOutputFunc 

pub type xmlCharEncodingOutputFunc = Option<unsafe extern "C" fn(out: *mut c_uchar, outlen: *mut c_int, in_: *const c_uchar, inlen: *mut c_int) -> c_int>;
Convert characters from UTF-8.

On success, the value of inlen after return is the number of bytes consumed and outlen is the number of bytes produced.

@param out a pointer to an array of bytes to store the result @param outlen the length of out @param in a pointer to an array of UTF-8 chars @param inlen the length of in @returns the number of bytes written or an xmlCharEncError code.

Aliased Type

pub enum xmlCharEncodingOutputFunc {
    None,
    Some(unsafe extern "C" fn(*mut u8, *mut i32, *const u8, *mut i32) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut u8, *mut i32, *const u8, *mut i32) -> i32)

Some value of type T.