pub type xmlHashTable = _xmlHashTable;Expand description
Hash table mapping strings to pointers
Also supports lookup using two or three strings as key.
Aliased Type
pub struct xmlHashTable { /* private fields */ }pub type xmlHashTable = _xmlHashTable;Hash table mapping strings to pointers
Also supports lookup using two or three strings as key.
pub struct xmlHashTable { /* private fields */ }