pub type xmlListWalker = Option<unsafe extern "C" fn(data: *const c_void, user: *mut c_void) -> c_int>;Expand description
Callback function used when walking a list with #xmlListWalk.
@param data the data found in the list @param user extra user provided data to the walker @returns 0 to stop walking the list, 1 otherwise.
Aliased Type
pub enum xmlListWalker {
None,
Some(unsafe extern "C" fn(*const c_void, *mut c_void) -> i32),
}