xmlNode

Type Alias xmlNode 

pub type xmlNode = _xmlNode;
Generic node type in an XML or HTML tree

Aliased Type

#[repr(C)]
pub struct xmlNode {
Show 16 fields pub _private: *mut c_void, pub type_: u32, pub name: *const u8, pub children: *mut _xmlNode, pub last: *mut _xmlNode, pub parent: *mut _xmlNode, pub next: *mut _xmlNode, pub prev: *mut _xmlNode, pub doc: *mut _xmlDoc, pub ns: *mut _xmlNs, pub content: *mut u8, pub properties: *mut _xmlAttr, pub nsDef: *mut _xmlNs, pub psvi: *mut c_void, pub line: u16, pub extra: u16,
}

Fields

_private: *mut c_void

Application data. Often used by language bindings.

type_: u32

Type enum, an xmlElementType value

name: *const u8

Name of the node.

  • Local name of elements or attributes. As a corner case, this can also contain Names which are invalid QNames in non-namespace-wellformed documents.
  • Name of entity references
  • Target of processing instructions
  • Fixed string for text and comments
  • Unused otherwise
children: *mut _xmlNode

First child. Entity declaration of entity references.

last: *mut _xmlNode

Last child

parent: *mut _xmlNode

Parent node. NULL for documents or unlinked root nodes.

next: *mut _xmlNode

Next sibling

prev: *mut _xmlNode

Previous sibling

doc: *mut _xmlDoc

Associated document.

Used to access DTDs, entities, ID tables, dictionary or other document properties. All children of a node share the same document.

ns: *mut _xmlNs

Namespace of element if any

content: *mut u8

Content of text, comment, PI nodes.

Sort index for elements after calling #xmlXPathOrderDocElems. Content of internal entities for entity references.

properties: *mut _xmlAttr

First attribute of element.

Also used to store small strings with XML_PARSE_COMPACT.

nsDef: *mut _xmlNs

First namespace definition of element

psvi: *mut c_void

For type/PSVI information

line: u16

Line number

extra: u16

Extra data for XPath/XSLT