xmlOutputWriteCallback

Type Alias xmlOutputWriteCallback 

pub type xmlOutputWriteCallback = Option<unsafe extern "C" fn(context: *mut c_void, buffer: *const c_char, len: c_int) -> c_int>;
Callback used in the I/O Output API to write to the resource

@param context an Output context @param buffer the buffer of data to write @param len the length of the buffer in bytes @returns the number of bytes written or -1 in case of error

Aliased Type

pub enum xmlOutputWriteCallback {
    None,
    Some(unsafe extern "C" fn(*mut c_void, *const i8, i32) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, *const i8, i32) -> i32)

Some value of type T.