xmlParserCtxt

Type Alias xmlParserCtxt 

pub type xmlParserCtxt = _xmlParserCtxt;
Parser context

Aliased Type

#[repr(C)]
pub struct xmlParserCtxt {
Show 102 fields pub sax: *mut _xmlSAXHandler, pub userData: *mut c_void, pub myDoc: *mut _xmlDoc, pub wellFormed: i32, pub replaceEntities: i32, pub version: *mut u8, pub encoding: *mut u8, pub standalone: i32, pub html: i32, pub input: *mut _xmlParserInput, pub inputNr: i32, pub inputMax: i32, pub inputTab: *mut *mut _xmlParserInput, pub node: *mut _xmlNode, pub nodeNr: i32, pub nodeMax: i32, pub nodeTab: *mut *mut _xmlNode, pub record_info: i32, pub node_seq: _xmlParserNodeInfoSeq, pub errNo: i32, pub hasExternalSubset: i32, pub hasPErefs: i32, pub external: i32, pub valid: i32, pub validate: i32, pub vctxt: _xmlValidCtxt, pub instate: i32, pub token: i32, pub directory: *mut i8, pub name: *const u8, pub nameNr: i32, pub nameMax: i32, pub nameTab: *mut *const u8, pub nbChars: i64, pub checkIndex: i64, pub keepBlanks: i32, pub disableSAX: i32, pub inSubset: i32, pub intSubName: *const u8, pub extSubURI: *mut u8, pub extSubSystem: *mut u8, pub space: *mut i32, pub spaceNr: i32, pub spaceMax: i32, pub spaceTab: *mut i32, pub depth: i32, pub entity: *mut _xmlParserInput, pub charset: i32, pub nodelen: i32, pub nodemem: i32, pub pedantic: i32, pub _private: *mut c_void, pub loadsubset: i32, pub linenumbers: i32, pub catalogs: *mut c_void, pub recovery: i32, pub progressive: i32, pub dict: *mut _xmlDict, pub atts: *mut *const u8, pub maxatts: i32, pub docdict: i32, pub str_xml: *const u8, pub str_xmlns: *const u8, pub str_xml_ns: *const u8, pub sax2: i32, pub nsNr: i32, pub nsMax: i32, pub nsTab: *mut *const u8, pub attallocs: *mut u32, pub pushTab: *mut _xmlStartTag, pub attsDefault: *mut _xmlHashTable, pub attsSpecial: *mut _xmlHashTable, pub nsWellFormed: i32, pub options: i32, pub dictNames: i32, pub freeElemsNr: i32, pub freeElems: *mut _xmlNode, pub freeAttrsNr: i32, pub freeAttrs: *mut _xmlAttr, pub lastError: _xmlError, pub parseMode: u32, pub nbentities: u64, pub sizeentities: u64, pub nodeInfo: *mut _xmlParserNodeInfo, pub nodeInfoNr: i32, pub nodeInfoMax: i32, pub nodeInfoTab: *mut _xmlParserNodeInfo, pub input_id: i32, pub sizeentcopy: u64, pub endCheckState: i32, pub nbErrors: u16, pub nbWarnings: u16, pub maxAmpl: u32, pub nsdb: *mut _xmlParserNsData, pub attrHashMax: u32, pub attrHash: *mut _xmlAttrHashBucket, pub errorHandler: Option<unsafe extern "C" fn(*mut c_void, *const _xmlError)>, pub errorCtxt: *mut c_void, pub resourceLoader: Option<unsafe extern "C" fn(*mut c_void, *const i8, *const i8, u32, u32, *mut *mut _xmlParserInput) -> u32>, pub resourceCtxt: *mut c_void, pub convImpl: Option<unsafe extern "C" fn(*mut c_void, *const i8, u32, *mut *mut _xmlCharEncodingHandler) -> u32>, pub convCtxt: *mut c_void,
}

Fields

sax: *mut _xmlSAXHandler

@deprecated Use xmlCtxtGetSaxHandler() and xmlCtxtSetSaxHandler().

the SAX handler

userData: *mut c_void

@deprecated Use #xmlCtxtGetUserData

user data for SAX interface, defaults to the context itself

myDoc: *mut _xmlDoc

@deprecated Use xmlCtxtGetDocument()

the document being built

wellFormed: i32

@deprecated Use xmlCtxtGetStatus()

is the document well formed?

replaceEntities: i32

@deprecated Use xmlParserOption XML_PARSE_NOENT

shall we replace entities?

version: *mut u8

@deprecated Use xmlCtxtGetVersion()

the XML version string

encoding: *mut u8

@deprecated Use xmlCtxtGetDeclaredEncoding()

the declared encoding, if any

standalone: i32

@deprecated Use xmlCtxtGetStandalone()

standalone document

html: i32

@deprecated Use xmlCtxtIsHtml()

non-zero for HTML documents, actually an htmlInsertMode

input: *mut _xmlParserInputinputNr: i32inputMax: i32inputTab: *mut *mut _xmlParserInputnode: *mut _xmlNode

@deprecated Use #xmlCtxtGetNode

The current element.

nodeNr: i32nodeMax: i32nodeTab: *mut *mut _xmlNoderecord_info: i32node_seq: _xmlParserNodeInfoSeqerrNo: i32

@deprecated Use xmlCtxtGetLastError()

error code

hasExternalSubset: i32hasPErefs: i32external: i32valid: i32

@deprecated Use xmlCtxtGetStatus()

is the document valid

validate: i32

@deprecated Use xmlParserOption XML_PARSE_DTDVALID

shall we try to validate?

vctxt: _xmlValidCtxt

@deprecated Use xmlCtxtGetValidCtxt()

The validity context

instate: i32token: i32directory: *mut i8

@deprecated Don’t use

The main document URI, if available, with its last component stripped.

name: *const u8nameNr: i32nameMax: i32nameTab: *mut *const u8nbChars: i64checkIndex: i64keepBlanks: i32

@deprecated Use inverted xmlParserOption XML_PARSE_NOBLANKS

ugly but …

disableSAX: i32

@deprecated Use xmlCtxtIsStopped()

SAX callbacks are disabled

inSubset: i32

@deprecated Use xmlCtxtIsInSubset

Set if DTD content is parsed.

  • 0: not in DTD
  • 1: in internal DTD subset
  • 2: in external DTD subset
intSubName: *const u8

@deprecated Use the name argument of the internalSubset SAX callback or #xmlCtxtGetDocTypeDecl

Name of the internal subset (root element type).

extSubURI: *mut u8

@deprecated Use the systemId argument of the internalSubset SAX callback or #xmlCtxtGetDocTypeDecl

System identifier (URI) of external the subset.

extSubSystem: *mut u8

@deprecated Use the publicId argument of the internalSubset SAX callback or #xmlCtxtGetDocTypeDecl

This member is MISNAMED. It contains the public identifier of the external subset.

space: *mut i32spaceNr: i32spaceMax: i32spaceTab: *mut i32depth: i32entity: *mut _xmlParserInputcharset: i32nodelen: i32nodemem: i32pedantic: i32

@deprecated Use xmlParserOption XML_PARSE_PEDANTIC

signal pedantic warnings

_private: *mut c_void

@deprecated Use xmlCtxtGetPrivate() and xmlCtxtSetPrivate()

For user data, libxml won’t touch it

loadsubset: i32

@deprecated Use xmlParserOption XML_PARSE_DTDLOAD, XML_PARSE_DTDATTR or XML_PARSE_SKIP_IDS.

Control loading of the external subset and handling of IDs. Other options like validate can override this value.

  • 0: The default behavior is to process IDs and to ignore the external subset.
  • XML_DETECT_IDS: Load external subset. This flag is misnamed. ID handling is only controlled by XML_SKIP_IDS.
  • XML_COMPLETE_ATTRS: Load external subset and process default attributes.
  • XML_SKIP_IDS: Ignore IDs.
linenumbers: i32catalogs: *mut c_void

@deprecated Use xmlCtxtGetCatalogs() and xmlCtxtSetCatalogs()

document’s own catalog

recovery: i32

@deprecated Use xmlParserOption XML_PARSE_RECOVER run in recovery mode

progressive: i32dict: *mut _xmlDict

@deprecated Use xmlCtxtGetDict() and xmlCtxtSetDict()

dictionary for the parser

atts: *mut *const u8maxatts: i32docdict: i32str_xml: *const u8str_xmlns: *const u8str_xml_ns: *const u8sax2: i32nsNr: i32nsMax: i32nsTab: *mut *const u8attallocs: *mut u32pushTab: *mut _xmlStartTagattsDefault: *mut _xmlHashTableattsSpecial: *mut _xmlHashTablensWellFormed: i32

@deprecated Use xmlCtxtGetStatus()

is the document XML Namespace okay

options: i32

@deprecated Use xmlCtxtGetOptions()

Extra options

dictNames: i32

@deprecated Use inverted xmlParserOption XML_PARSE_NODICT

Use dictionary names for the tree

freeElemsNr: i32freeElems: *mut _xmlNodefreeAttrsNr: i32freeAttrs: *mut _xmlAttrlastError: _xmlError

@deprecated Use xmlCtxtGetLastError()

the complete error information for the last error.

parseMode: u32nbentities: u64sizeentities: u64nodeInfo: *mut _xmlParserNodeInfonodeInfoNr: i32nodeInfoMax: i32nodeInfoTab: *mut _xmlParserNodeInfoinput_id: i32sizeentcopy: u64endCheckState: i32nbErrors: u16nbWarnings: u16maxAmpl: u32nsdb: *mut _xmlParserNsDataattrHashMax: u32attrHash: *mut _xmlAttrHashBucketerrorHandler: Option<unsafe extern "C" fn(*mut c_void, *const _xmlError)>errorCtxt: *mut c_voidresourceLoader: Option<unsafe extern "C" fn(*mut c_void, *const i8, *const i8, u32, u32, *mut *mut _xmlParserInput) -> u32>resourceCtxt: *mut c_voidconvImpl: Option<unsafe extern "C" fn(*mut c_void, *const i8, u32, *mut *mut _xmlCharEncodingHandler) -> u32>convCtxt: *mut c_void