pub type xmlReallocFunc = Option<unsafe extern "C" fn(mem: *mut c_void, size: usize) -> *mut c_void>;Expand description
Signature for a realloc() implementation.
@param mem an already allocated block of memory @param size the new size requested in bytes @returns a pointer to the newly reallocated block or NULL in case of error.
Aliased Type
pub enum xmlReallocFunc {
None,
Some(unsafe extern "C" fn(*mut c_void, usize) -> *mut c_void),
}