pub type xmlSchemaValidityLocatorFunc = Option<unsafe extern "C" fn(ctx: *mut c_void, file: *mut *const c_char, line: *mut c_ulong) -> c_int>;Expand description
A schemas validation locator, a callback called by the validator. This is used when file or node information are not available to find out what file and line number are affected
@param ctx user provided context @param file returned file information @param line returned line information @returns 0 in case of success and -1 in case of error
Aliased Type
pub enum xmlSchemaValidityLocatorFunc {
None,
Some(unsafe extern "C" fn(*mut c_void, *mut *const i8, *mut u64) -> i32),
}