#[repr(C)]pub struct _xmlParserCtxt {Show 102 fields
pub sax: *mut _xmlSAXHandler,
pub userData: *mut c_void,
pub myDoc: *mut xmlDoc,
pub wellFormed: c_int,
pub replaceEntities: c_int,
pub version: *mut xmlChar,
pub encoding: *mut xmlChar,
pub standalone: c_int,
pub html: c_int,
pub input: *mut xmlParserInput,
pub inputNr: c_int,
pub inputMax: c_int,
pub inputTab: *mut *mut xmlParserInput,
pub node: *mut xmlNode,
pub nodeNr: c_int,
pub nodeMax: c_int,
pub nodeTab: *mut *mut xmlNode,
pub record_info: c_int,
pub node_seq: xmlParserNodeInfoSeq,
pub errNo: c_int,
pub hasExternalSubset: c_int,
pub hasPErefs: c_int,
pub external: c_int,
pub valid: c_int,
pub validate: c_int,
pub vctxt: xmlValidCtxt,
pub instate: xmlParserInputState,
pub token: c_int,
pub directory: *mut c_char,
pub name: *const xmlChar,
pub nameNr: c_int,
pub nameMax: c_int,
pub nameTab: *mut *const xmlChar,
pub nbChars: c_long,
pub checkIndex: c_long,
pub keepBlanks: c_int,
pub disableSAX: c_int,
pub inSubset: c_int,
pub intSubName: *const xmlChar,
pub extSubURI: *mut xmlChar,
pub extSubSystem: *mut xmlChar,
pub space: *mut c_int,
pub spaceNr: c_int,
pub spaceMax: c_int,
pub spaceTab: *mut c_int,
pub depth: c_int,
pub entity: *mut xmlParserInput,
pub charset: c_int,
pub nodelen: c_int,
pub nodemem: c_int,
pub pedantic: c_int,
pub _private: *mut c_void,
pub loadsubset: c_int,
pub linenumbers: c_int,
pub catalogs: *mut c_void,
pub recovery: c_int,
pub progressive: c_int,
pub dict: *mut xmlDict,
pub atts: *mut *const xmlChar,
pub maxatts: c_int,
pub docdict: c_int,
pub str_xml: *const xmlChar,
pub str_xmlns: *const xmlChar,
pub str_xml_ns: *const xmlChar,
pub sax2: c_int,
pub nsNr: c_int,
pub nsMax: c_int,
pub nsTab: *mut *const xmlChar,
pub attallocs: *mut c_uint,
pub pushTab: *mut xmlStartTag,
pub attsDefault: *mut xmlHashTable,
pub attsSpecial: *mut xmlHashTable,
pub nsWellFormed: c_int,
pub options: c_int,
pub dictNames: c_int,
pub freeElemsNr: c_int,
pub freeElems: *mut xmlNode,
pub freeAttrsNr: c_int,
pub freeAttrs: *mut xmlAttr,
pub lastError: xmlError,
pub parseMode: xmlParserMode,
pub nbentities: c_ulong,
pub sizeentities: c_ulong,
pub nodeInfo: *mut xmlParserNodeInfo,
pub nodeInfoNr: c_int,
pub nodeInfoMax: c_int,
pub nodeInfoTab: *mut xmlParserNodeInfo,
pub input_id: c_int,
pub sizeentcopy: c_ulong,
pub endCheckState: c_int,
pub nbErrors: c_ushort,
pub nbWarnings: c_ushort,
pub maxAmpl: c_uint,
pub nsdb: *mut xmlParserNsData,
pub attrHashMax: c_uint,
pub attrHash: *mut xmlAttrHashBucket,
pub errorHandler: xmlStructuredErrorFunc,
pub errorCtxt: *mut c_void,
pub resourceLoader: xmlResourceLoader,
pub resourceCtxt: *mut c_void,
pub convImpl: xmlCharEncConvImpl,
pub convCtxt: *mut c_void,
}Expand description
Parser context
Fields
sax: *mut _xmlSAXHandler@deprecated Use xmlCtxtGetSaxHandler() and xmlCtxtSetSaxHandler().
the SAX handler
userData: *mut c_void@deprecated Use #xmlCtxtGetUserData
user data for SAX interface, defaults to the context itself
myDoc: *mut xmlDoc@deprecated Use xmlCtxtGetDocument()
the document being built
wellFormed: c_int@deprecated Use xmlCtxtGetStatus()
is the document well formed?
replaceEntities: c_int@deprecated Use xmlParserOption XML_PARSE_NOENT
shall we replace entities?
version: *mut xmlChar@deprecated Use xmlCtxtGetVersion()
the XML version string
encoding: *mut xmlChar@deprecated Use xmlCtxtGetDeclaredEncoding()
the declared encoding, if any
standalone: c_int@deprecated Use xmlCtxtGetStandalone()
standalone document
html: c_int@deprecated Use xmlCtxtIsHtml()
non-zero for HTML documents, actually an htmlInsertMode
input: *mut xmlParserInputinputNr: c_intinputMax: c_intinputTab: *mut *mut xmlParserInputnode: *mut xmlNode@deprecated Use #xmlCtxtGetNode
The current element.
nodeNr: c_intnodeMax: c_intnodeTab: *mut *mut xmlNoderecord_info: c_intnode_seq: xmlParserNodeInfoSeqerrNo: c_int@deprecated Use xmlCtxtGetLastError()
error code
hasExternalSubset: c_inthasPErefs: c_intexternal: c_intvalid: c_int@deprecated Use xmlCtxtGetStatus()
is the document valid
validate: c_int@deprecated Use xmlParserOption XML_PARSE_DTDVALID
shall we try to validate?
vctxt: xmlValidCtxt@deprecated Use xmlCtxtGetValidCtxt()
The validity context
instate: xmlParserInputStatetoken: c_intdirectory: *mut c_char@deprecated Don’t use
The main document URI, if available, with its last component stripped.
name: *const xmlCharnameNr: c_intnameMax: c_intnameTab: *mut *const xmlCharnbChars: c_longcheckIndex: c_longkeepBlanks: c_int@deprecated Use inverted xmlParserOption XML_PARSE_NOBLANKS
ugly but …
disableSAX: c_int@deprecated Use xmlCtxtIsStopped()
SAX callbacks are disabled
inSubset: c_int@deprecated Use xmlCtxtIsInSubset
Set if DTD content is parsed.
- 0: not in DTD
- 1: in internal DTD subset
- 2: in external DTD subset
intSubName: *const xmlChar@deprecated Use the name argument of the
internalSubset SAX callback or #xmlCtxtGetDocTypeDecl
Name of the internal subset (root element type).
extSubURI: *mut xmlChar@deprecated Use the systemId argument of the
internalSubset SAX callback or #xmlCtxtGetDocTypeDecl
System identifier (URI) of external the subset.
extSubSystem: *mut xmlChar@deprecated Use the publicId argument of the
internalSubset SAX callback or #xmlCtxtGetDocTypeDecl
This member is MISNAMED. It contains the public identifier of the external subset.
space: *mut c_intspaceNr: c_intspaceMax: c_intspaceTab: *mut c_intdepth: c_intentity: *mut xmlParserInputcharset: c_intnodelen: c_intnodemem: c_intpedantic: c_int@deprecated Use xmlParserOption XML_PARSE_PEDANTIC
signal pedantic warnings
_private: *mut c_void@deprecated Use xmlCtxtGetPrivate() and xmlCtxtSetPrivate()
For user data, libxml won’t touch it
loadsubset: c_int@deprecated Use xmlParserOption XML_PARSE_DTDLOAD, XML_PARSE_DTDATTR or XML_PARSE_SKIP_IDS.
Control loading of the external subset and handling of IDs.
Other options like validate can override this value.
- 0: The default behavior is to process IDs and to ignore the external subset.
- XML_DETECT_IDS: Load external subset. This flag is misnamed. ID handling is only controlled by XML_SKIP_IDS.
- XML_COMPLETE_ATTRS: Load external subset and process default attributes.
- XML_SKIP_IDS: Ignore IDs.
linenumbers: c_intcatalogs: *mut c_void@deprecated Use xmlCtxtGetCatalogs() and xmlCtxtSetCatalogs()
document’s own catalog
recovery: c_int@deprecated Use xmlParserOption XML_PARSE_RECOVER run in recovery mode
progressive: c_intdict: *mut xmlDict@deprecated Use xmlCtxtGetDict() and xmlCtxtSetDict()
dictionary for the parser
atts: *mut *const xmlCharmaxatts: c_intdocdict: c_intstr_xml: *const xmlCharstr_xmlns: *const xmlCharstr_xml_ns: *const xmlCharsax2: c_intnsNr: c_intnsMax: c_intnsTab: *mut *const xmlCharattallocs: *mut c_uintpushTab: *mut xmlStartTagattsDefault: *mut xmlHashTableattsSpecial: *mut xmlHashTablensWellFormed: c_int@deprecated Use xmlCtxtGetStatus()
is the document XML Namespace okay
options: c_int@deprecated Use xmlCtxtGetOptions()
Extra options
dictNames: c_int@deprecated Use inverted xmlParserOption XML_PARSE_NODICT
Use dictionary names for the tree
freeElemsNr: c_intfreeElems: *mut xmlNodefreeAttrsNr: c_intfreeAttrs: *mut xmlAttrlastError: xmlError@deprecated Use xmlCtxtGetLastError()
the complete error information for the last error.
parseMode: xmlParserModenbentities: c_ulongsizeentities: c_ulongnodeInfo: *mut xmlParserNodeInfonodeInfoNr: c_intnodeInfoMax: c_intnodeInfoTab: *mut xmlParserNodeInfoinput_id: c_intsizeentcopy: c_ulongendCheckState: c_intnbErrors: c_ushortnbWarnings: c_ushortmaxAmpl: c_uintnsdb: *mut xmlParserNsDataattrHashMax: c_uintattrHash: *mut xmlAttrHashBucketerrorHandler: xmlStructuredErrorFuncerrorCtxt: *mut c_voidresourceLoader: xmlResourceLoaderresourceCtxt: *mut c_voidconvImpl: xmlCharEncConvImplconvCtxt: *mut c_voidTrait Implementations
Sourceimpl Clone for _xmlParserCtxt
impl Clone for _xmlParserCtxt
Sourcefn clone(&self) -> _xmlParserCtxt
fn clone(&self) -> _xmlParserCtxt
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more