pub type endElementNsSAX2Func = Option<unsafe extern "C" fn(ctx: *mut c_void, localname: *const xmlChar, prefix: *const xmlChar, URI: *const xmlChar)>;Expand description
SAX2 callback for end tags.
It provides the namespace information for the element.
@param ctx the user data (XML parser context) @param localname the local name of the element @param prefix the element namespace prefix if available @param URI the element namespace name if available
Aliased Type
pub enum endElementNsSAX2Func {
None,
Some(unsafe extern "C" fn(*mut c_void, *const u8, *const u8, *const u8)),
}