startElementNsSAX2Func

Type Alias startElementNsSAX2Func 

pub type startElementNsSAX2Func = Option<unsafe extern "C" fn(ctx: *mut c_void, localname: *const xmlChar, prefix: *const xmlChar, URI: *const xmlChar, nb_namespaces: c_int, namespaces: *mut *const xmlChar, nb_attributes: c_int, nb_defaulted: c_int, attributes: *mut *const xmlChar)>;
SAX2 callback for start tags.

It provides the namespace information for the element, as well as the new namespace declarations on the element.

@param ctx the user data (XML parser context) @param localname the local name of the element @param prefix the element namespace prefix if available @param URI the element namespace name if available @param nb_namespaces number of namespace definitions on that node @param namespaces pointer to the array of prefix/URI pairs namespace definitions @param nb_attributes the number of attributes on that node @param nb_defaulted the number of defaulted attributes. The defaulted ones are at the end of the array @param attributes pointer to the array of (localname/prefix/URI/value/end) attribute values.

Aliased Type

pub enum startElementNsSAX2Func {
    None,
    Some(unsafe extern "C" fn(*mut c_void, *const u8, *const u8, *const u8, i32, *mut *const u8, i32, i32, *mut *const u8)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, *const u8, *const u8, *const u8, i32, *mut *const u8, i32, i32, *mut *const u8))

Some value of type T.