pub type xmlCharEncConvFunc = Option<unsafe extern "C" fn(vctxt: *mut c_void, out: *mut c_uchar, outlen: *mut c_int, in_: *const c_uchar, inlen: *mut c_int, flush: c_int) -> xmlCharEncError>;Expand description
Convert between character encodings.
The value of inlen after return is the number of bytes consumed
and outlen is the number of bytes produced.
If the converter can consume partial multi-byte sequences, the
flush flag can be used to detect truncated sequences at EOF.
Otherwise, the flag can be ignored.
@param vctxt conversion context
@param out a pointer to an array of bytes to store the result
@param outlen the length of out
@param in a pointer to an array of input bytes
@param inlen the length of in
@param flush end of input
@returns an xmlCharEncError code.
Aliased Type
pub enum xmlCharEncConvFunc {
None,
Some(unsafe extern "C" fn(*mut c_void, *mut u8, *mut i32, *const u8, *mut i32, i32) -> i32),
}