pub type xmlNode = _xmlNode;Expand description
Generic node type in an XML or HTML tree
Aliased Type
#[repr(C)]pub struct xmlNode {Show 16 fields
pub _private: *mut c_void,
pub type_: u32,
pub name: *const u8,
pub children: *mut _xmlNode,
pub last: *mut _xmlNode,
pub parent: *mut _xmlNode,
pub next: *mut _xmlNode,
pub prev: *mut _xmlNode,
pub doc: *mut _xmlDoc,
pub ns: *mut _xmlNs,
pub content: *mut u8,
pub properties: *mut _xmlAttr,
pub nsDef: *mut _xmlNs,
pub psvi: *mut c_void,
pub line: u16,
pub extra: u16,
}Fields
_private: *mut c_voidApplication data. Often used by language bindings.
type_: u32Type enum, an xmlElementType value
name: *const u8Name of the node.
- Local name of elements or attributes. As a corner case, this can also contain Names which are invalid QNames in non-namespace-wellformed documents.
- Name of entity references
- Target of processing instructions
- Fixed string for text and comments
- Unused otherwise
children: *mut _xmlNodeFirst child. Entity declaration of entity references.
last: *mut _xmlNodeLast child
parent: *mut _xmlNodeParent node. NULL for documents or unlinked root nodes.
next: *mut _xmlNodeNext sibling
prev: *mut _xmlNodePrevious sibling
doc: *mut _xmlDocAssociated document.
Used to access DTDs, entities, ID tables, dictionary or other document properties. All children of a node share the same document.
ns: *mut _xmlNsNamespace of element if any
content: *mut u8Content of text, comment, PI nodes.
Sort index for elements after calling #xmlXPathOrderDocElems. Content of internal entities for entity references.
properties: *mut _xmlAttrFirst attribute of element.
Also used to store small strings with XML_PARSE_COMPACT.
nsDef: *mut _xmlNsFirst namespace definition of element
psvi: *mut c_voidFor type/PSVI information
line: u16Line number
extra: u16Extra data for XPath/XSLT